@@ -3,7 +3,7 @@ Module handling NPM related features
 """
 import json
 from pathlib import Path
-from typing import TYPE_CHECKING, Optional, Union
+from typing import TYPE_CHECKING, Optional, Union, Dict
 
 # Cycle dependency
 if TYPE_CHECKING:
@@ -11,11 +11,13 @@ if TYPE_CHECKING:
 
 
 def get_package_name(target_txt: Union[str, "SolcStandardJson"]) -> Optional[str]:
-    """
-    Return the package's name
+    """Return the npm package's name
 
-    :param target_txt:
-    :return: str or None
+    Args:
+        target_txt (Union[str,SolcStandardJson): path to the target
+
+    Returns:
+        Optional[str]: npm package name
     """
 
     # Verify the target path is a string (exported zip archives are lists)
@@ -30,7 +32,7 @@ def get_package_name(target_txt: Union[str, "SolcStandardJson"]) -> Optional[str
             if package.exists():
                 with open(package) as file_desc:
                     try:
-                        package_dict = json.load(file_desc)
+                        package_dict: Dict[str, str] = json.load(file_desc)
                         return package_dict.get("name", None)
                     except json.JSONDecodeError:
                         return None
